@@ -1,12 +1,14 @@
 /*
- * Copyright 2019-2025 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2019-2026 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
  * in the file LICENSE in the source distribution or at
  * https://www.openssl.org/source/license.html
  */
+/* clang-format off */
 
+/* clang-format on */
 
 /*
  * RSA low level APIs are deprecated for public use, but still ok for
@@ -47,11 +49,11 @@ static OSSL_FUNC_asym_cipher_set_ctx_params_fn rsa_set_ctx_params;
 static OSSL_FUNC_asym_cipher_settable_ctx_params_fn rsa_settable_ctx_params;
 
 static OSSL_ITEM padding_item[] = {
-    { RSA_PKCS1_PADDING,        OSSL_PKEY_RSA_PAD_MODE_PKCSV15 },
-    { RSA_NO_PADDING,           OSSL_PKEY_RSA_PAD_MODE_NONE },
-    { RSA_PKCS1_OAEP_PADDING,   OSSL_PKEY_RSA_PAD_MODE_OAEP }, /* Correct spelling first */
-    { RSA_PKCS1_OAEP_PADDING,   "oeap"   },
-    { 0,                        NULL     }
+    { RSA_PKCS1_PADDING, OSSL_PKEY_RSA_PAD_MODE_PKCSV15 },
+    { RSA_NO_PADDING, OSSL_PKEY_RSA_PAD_MODE_NONE },
+    { RSA_PKCS1_OAEP_PADDING, OSSL_PKEY_RSA_PAD_MODE_OAEP }, /* Correct spelling first */
+    { RSA_PKCS1_OAEP_PADDING, "oeap" },
+    { 0, NULL }
 };
 
 /*
@@ -96,7 +98,7 @@ static void *rsa_newctx(void *provctx)
 }
 
 static int rsa_init(void *vprsactx, void *vrsa, const OSSL_PARAM params[],
-                    int operation, const char *desc)
+    int operation, const char *desc)
 {
     PROV_RSA_CTX *prsactx = (PROV_RSA_CTX *)vprsactx;
     int protect = 0;
@@ -128,29 +130,29 @@ static int rsa_init(void *vprsactx, void *vrsa, const OSSL_PARAM params[],
         return 0;
 #ifdef FIPS_MODULE
     if (!ossl_fips_ind_rsa_key_check(OSSL_FIPS_IND_GET(prsactx),
-                                     OSSL_FIPS_IND_SETTABLE0, prsactx->libctx,
-                                     prsactx->rsa, desc, protect))
+            OSSL_FIPS_IND_SETTABLE0, prsactx->libctx,
+            prsactx->rsa, desc, protect))
         return 0;
 #endif
     return 1;
 }
 
 static int rsa_encrypt_init(void *vprsactx, void *vrsa,
-                            const OSSL_PARAM params[])
+    const OSSL_PARAM params[])
 {
     return rsa_init(vprsactx, vrsa, params, EVP_PKEY_OP_ENCRYPT,
-                    "RSA Encrypt Init");
+        "RSA Encrypt Init");
 }
 
 static int rsa_decrypt_init(void *vprsactx, void *vrsa,
-                            const OSSL_PARAM params[])
+    const OSSL_PARAM params[])
 {
     return rsa_init(vprsactx, vrsa, params, EVP_PKEY_OP_DECRYPT,
-                    "RSA Decrypt Init");
+        "RSA Decrypt Init");
 }
 
 static int rsa_encrypt(void *vprsactx, unsigned char *out, size_t *outlen,
-                       size_t outsize, const unsigned char *in, size_t inlen)
+    size_t outsize, const unsigned char *in, size_t inlen)
 {
     PROV_RSA_CTX *prsactx = (PROV_RSA_CTX *)vprsactx;
     size_t len = RSA_size(prsactx->rsa);
@@ -161,11 +163,11 @@ static int rsa_encrypt(void *vprsactx, unsigned char *out, size_t *outlen,
 
 #ifdef FIPS_MODULE
     if ((prsactx->pad_mode == RSA_PKCS1_PADDING
-         || prsactx->pad_mode == RSA_PKCS1_WITH_TLS_PADDING)
+            || prsactx->pad_mode == RSA_PKCS1_WITH_TLS_PADDING)
         && !OSSL_FIPS_IND_ON_UNAPPROVED(prsactx, OSSL_FIPS_IND_SETTABLE1,
-                                        prsactx->libctx, "RSA Encrypt",
-                                        "PKCS#1 v1.5 padding",
-                                        ossl_fips_config_rsa_pkcs15_padding_disabled)) {
+            prsactx->libctx, "RSA Encrypt",
+            "PKCS#1 v1.5 padding",
+            ossl_fips_config_rsa_pkcs15_padding_disabled)) {
         ERR_raise(ERR_LIB_PROV, PROV_R_INVALID_PADDING_MODE);
         return 0;
     }
@@ -200,24 +202,23 @@ static int rsa_encrypt(void *vprsactx, unsigned char *out, size_t *outlen,
                 return 0;
             }
         }
-        ret =
-            ossl_rsa_padding_add_PKCS1_OAEP_mgf1_ex(prsactx->libctx, tbuf,
-                                                    rsasize, in, (int)inlen,
-                                                    prsactx->oaep_label,
-                                                    (int)prsactx->oaep_labellen,
-                                                    prsactx->oaep_md,
-                                                    prsactx->mgf1_md);
+        ret = ossl_rsa_padding_add_PKCS1_OAEP_mgf1_ex(prsactx->libctx, tbuf,
+            rsasize, in, (int)inlen,
+            prsactx->oaep_label,
+            (int)prsactx->oaep_labellen,
+            prsactx->oaep_md,
+            prsactx->mgf1_md);
 
         if (!ret) {
             OPENSSL_free(tbuf);
             return 0;
         }
         ret = RSA_public_encrypt(rsasize, tbuf, out, prsactx->rsa,
-                                 RSA_NO_PADDING);
+            RSA_NO_PADDING);
         OPENSSL_free(tbuf);
     } else {
         ret = RSA_public_encrypt((int)inlen, in, out, prsactx->rsa,
-                                 prsactx->pad_mode);
+            prsactx->pad_mode);
     }
     /* A ret value of 0 is not an error */
     if (ret < 0)
@@ -227,7 +228,7 @@ static int rsa_encrypt(void *vprsactx, unsigned char *out, size_t *outlen,
 }
 
 static int rsa_decrypt(void *vprsactx, unsigned char *out, size_t *outlen,
-                       size_t outsize, const unsigned char *in, size_t inlen)
+    size_t outsize, const unsigned char *in, size_t inlen)
 {
     PROV_RSA_CTX *prsactx = (PROV_RSA_CTX *)vprsactx;
     int ret;
@@ -263,13 +264,13 @@ static int rsa_decrypt(void *vprsactx, unsigned char *out, size_t *outlen,
     }
 
     if (prsactx->pad_mode == RSA_PKCS1_OAEP_PADDING
-            || prsactx->pad_mode == RSA_PKCS1_WITH_TLS_PADDING) {
+        || prsactx->pad_mode == RSA_PKCS1_WITH_TLS_PADDING) {
         unsigned char *tbuf;
 
         if ((tbuf = OPENSSL_malloc(len)) == NULL)
             return 0;
         ret = RSA_private_decrypt((int)inlen, in, tbuf, prsactx->rsa,
-                                  RSA_NO_PADDING);
+            RSA_NO_PADDING);
         /*
          * With no padding then, on success ret should be len, otherwise an
          * error occurred (non-constant time)
@@ -289,11 +290,11 @@ static int rsa_decrypt(void *vprsactx, unsigned char *out, size_t *outlen,
                 }
             }
             ret = RSA_padding_check_PKCS1_OAEP_mgf1(out, (int)outsize, tbuf,
-                                                    (int)len, (int)len,
-                                                    prsactx->oaep_label,
-                                                    (int)prsactx->oaep_labellen,
-                                                    prsactx->oaep_md,
-                                                    prsactx->mgf1_md);
+                (int)len, (int)len,
+                prsactx->oaep_label,
+                (int)prsactx->oaep_labellen,
+                prsactx->oaep_md,
+                prsactx->mgf1_md);
         } else {
             /* RSA_PKCS1_WITH_TLS_PADDING */
             if (prsactx->client_version <= 0) {
@@ -302,13 +303,12 @@ static int rsa_decrypt(void *vprsactx, unsigned char *out, size_t *outlen,
                 return 0;
             }
             ret = ossl_rsa_padding_check_PKCS1_type_2_TLS(
-                        prsactx->libctx, out, outsize, tbuf, len,
-                        prsactx->client_version, prsactx->alt_version);
+                prsactx->libctx, out, outsize, tbuf, len,
+                prsactx->client_version, prsactx->alt_version);
         }
         OPENSSL_free(tbuf);
     } else {
-        if ((prsactx->implicit_rejection == 0) &&
-                (prsactx->pad_mode == RSA_PKCS1_PADDING))
+        if ((prsactx->implicit_rejection == 0) && (prsactx->pad_mode == RSA_PKCS1_PADDING))
             pad_mode = RSA_PKCS1_NO_IMPLICIT_REJECT_PADDING;
         else
             pad_mode = prsactx->pad_mode;
@@ -363,9 +363,16 @@ static void *rsa_dupctx(void *vprsactx)
         return NULL;
     }
 
+    if (dstctx->oaep_label != NULL
+        && (dstctx->oaep_label = OPENSSL_memdup(dstctx->oaep_label, dstctx->oaep_labellen)) == NULL) {
+        rsa_freectx(dstctx);
+        return NULL;
+    }
+
     return dstctx;
 }
 
+/* clang-format off */
 /* Machine generated by util/perl/OpenSSL/paramnames.pm */
 #ifndef rsa_get_ctx_params_list
 static const OSSL_PARAM rsa_get_ctx_params_list[] = {
@@ -525,6 +532,7 @@ static int rsa_get_ctx_params_decoder
 }
 #endif
 /* End of machine generated */
+/* clang-format on */
 
 static int rsa_get_ctx_params(void *vprsactx, OSSL_PARAM *params)
 {
@@ -559,36 +567,32 @@ static int rsa_get_ctx_params(void *vprsactx, OSSL_PARAM *params)
         }
     }
 
-    if (p.oaep != NULL && !OSSL_PARAM_set_utf8_string(p.oaep, prsactx->oaep_md == NULL
-                                                              ? ""
-                                                              : EVP_MD_get0_name(prsactx->oaep_md)))
+    if (p.oaep != NULL && !OSSL_PARAM_set_utf8_string(p.oaep, prsactx->oaep_md == NULL ? "" : EVP_MD_get0_name(prsactx->oaep_md)))
         return 0;
 
     if (p.mgf1 != NULL) {
         EVP_MD *mgf1_md = prsactx->mgf1_md == NULL ? prsactx->oaep_md
                                                    : prsactx->mgf1_md;
 
-        if (!OSSL_PARAM_set_utf8_string(p.mgf1, mgf1_md == NULL
-                                                ? ""
-                                                : EVP_MD_get0_name(mgf1_md)))
-        return 0;
+        if (!OSSL_PARAM_set_utf8_string(p.mgf1, mgf1_md == NULL ? "" : EVP_MD_get0_name(mgf1_md)))
+            return 0;
     }
 
     if (p.label != NULL
-            && !OSSL_PARAM_set_octet_ptr(p.label, prsactx->oaep_label,
-                                         prsactx->oaep_labellen))
+        && !OSSL_PARAM_set_octet_ptr(p.label, prsactx->oaep_label,
+            prsactx->oaep_labellen))
         return 0;
 
     if (p.tlsver != NULL
-            && !OSSL_PARAM_set_uint(p.tlsver, prsactx->client_version))
+        && !OSSL_PARAM_set_uint(p.tlsver, prsactx->client_version))
         return 0;
 
     if (p.negver != NULL
-            && !OSSL_PARAM_set_uint(p.negver, prsactx->alt_version))
+        && !OSSL_PARAM_set_uint(p.negver, prsactx->alt_version))
         return 0;
 
     if (p.imrej != NULL
-            && !OSSL_PARAM_set_uint(p.imrej, prsactx->implicit_rejection))
+        && !OSSL_PARAM_set_uint(p.imrej, prsactx->implicit_rejection))
         return 0;
 
     if (!OSSL_FIPS_IND_GET_CTX_FROM_PARAM(prsactx, p.ind))
@@ -597,13 +601,13 @@ static int rsa_get_ctx_params(void *vprsactx, OSSL_PARAM *params)
     return 1;
 }
 
-
 static const OSSL_PARAM *rsa_gettable_ctx_params(ossl_unused void *vprsactx,
-                                                 ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     return rsa_get_ctx_params_list;
 }
 
+/* clang-format off */
 /* Machine generated by util/perl/OpenSSL/paramnames.pm */
 #ifndef rsa_set_ctx_params_list
 static const OSSL_PARAM rsa_set_ctx_params_list[] = {
@@ -860,6 +864,7 @@ static int rsa_set_ctx_params_decoder
 }
 #endif
 /* End of machine generated */
+/* clang-format on */
 
 static int rsa_set_ctx_params(void *vprsactx, const OSSL_PARAM params[])
 {
@@ -988,7 +993,7 @@ static int rsa_set_ctx_params(void *vprsactx, const OSSL_PARAM params[])
 }
 
 static const OSSL_PARAM *rsa_settable_ctx_params(ossl_unused void *vprsactx,
-                                                 ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     return rsa_set_ctx_params_list;
 }
@@ -1002,12 +1007,12 @@ const OSSL_DISPATCH ossl_rsa_asym_cipher_functions[] = {
     { OSSL_FUNC_ASYM_CIPHER_FREECTX, (void (*)(void))rsa_freectx },
     { OSSL_FUNC_ASYM_CIPHER_DUPCTX, (void (*)(void))rsa_dupctx },
     { OSSL_FUNC_ASYM_CIPHER_GET_CTX_PARAMS,
-      (void (*)(void))rsa_get_ctx_params },
+        (void (*)(void))rsa_get_ctx_params },
     { OSSL_FUNC_ASYM_CIPHER_GETTABLE_CTX_PARAMS,
-      (void (*)(void))rsa_gettable_ctx_params },
+        (void (*)(void))rsa_gettable_ctx_params },
     { OSSL_FUNC_ASYM_CIPHER_SET_CTX_PARAMS,
-      (void (*)(void))rsa_set_ctx_params },
+        (void (*)(void))rsa_set_ctx_params },
     { OSSL_FUNC_ASYM_CIPHER_SETTABLE_CTX_PARAMS,
-      (void (*)(void))rsa_settable_ctx_params },
+        (void (*)(void))rsa_settable_ctx_params },
     OSSL_DISPATCH_END
 };
