@@ -9,7 +9,9 @@
  * RFC 9106 Argon2 (see https://www.rfc-editor.org/rfc/rfc9106.txt)
  *
  */
+/* clang-format off */
 
+/* clang-format on */
 
 #include <stdlib.h>
 #include <stddef.h>
@@ -35,101 +37,99 @@
 #include "prov/blake2.h"
 
 #if defined(OPENSSL_NO_DEFAULT_THREAD_POOL) && defined(OPENSSL_NO_THREAD_POOL)
-# define ARGON2_NO_THREADS
+#define ARGON2_NO_THREADS
 #endif
 
 #if !defined(OPENSSL_THREADS)
-# define ARGON2_NO_THREADS
+#define ARGON2_NO_THREADS
 #endif
 
 #ifndef OPENSSL_NO_ARGON2
 
-# define ARGON2_MIN_LANES 1u
-# define ARGON2_MAX_LANES 0xFFFFFFu
-# define ARGON2_MIN_THREADS 1u
-# define ARGON2_MAX_THREADS 0xFFFFFFu
-# define ARGON2_SYNC_POINTS 4u
-# define ARGON2_MIN_OUT_LENGTH 4u
-# define ARGON2_MAX_OUT_LENGTH 0xFFFFFFFFu
-# define ARGON2_MIN_MEMORY (2 * ARGON2_SYNC_POINTS)
-# define ARGON2_MIN(a, b) ((a) < (b) ? (a) : (b))
-# define ARGON2_MAX_MEMORY 0xFFFFFFFFu
-# define ARGON2_MIN_TIME 1u
-# define ARGON2_MAX_TIME 0xFFFFFFFFu
-# define ARGON2_MIN_PWD_LENGTH 0u
-# define ARGON2_MAX_PWD_LENGTH 0xFFFFFFFFu
-# define ARGON2_MIN_AD_LENGTH 0u
-# define ARGON2_MAX_AD_LENGTH 0xFFFFFFFFu
-# define ARGON2_MIN_SALT_LENGTH 8u
-# define ARGON2_MAX_SALT_LENGTH 0xFFFFFFFFu
-# define ARGON2_MIN_SECRET 0u
-# define ARGON2_MAX_SECRET 0xFFFFFFFFu
-# define ARGON2_BLOCK_SIZE 1024
-# define ARGON2_QWORDS_IN_BLOCK ((ARGON2_BLOCK_SIZE) / 8)
-# define ARGON2_OWORDS_IN_BLOCK ((ARGON2_BLOCK_SIZE) / 16)
-# define ARGON2_HWORDS_IN_BLOCK ((ARGON2_BLOCK_SIZE) / 32)
-# define ARGON2_512BIT_WORDS_IN_BLOCK ((ARGON2_BLOCK_SIZE) / 64)
-# define ARGON2_ADDRESSES_IN_BLOCK 128
-# define ARGON2_PREHASH_DIGEST_LENGTH 64
-# define ARGON2_PREHASH_SEED_LENGTH \
+#define ARGON2_MIN_LANES 1u
+#define ARGON2_MAX_LANES 0xFFFFFFu
+#define ARGON2_MIN_THREADS 1u
+#define ARGON2_MAX_THREADS 0xFFFFFFu
+#define ARGON2_SYNC_POINTS 4u
+#define ARGON2_MIN_OUT_LENGTH 4u
+#define ARGON2_MAX_OUT_LENGTH 0xFFFFFFFFu
+#define ARGON2_MIN_MEMORY (2 * ARGON2_SYNC_POINTS)
+#define ARGON2_MIN(a, b) ((a) < (b) ? (a) : (b))
+#define ARGON2_MAX_MEMORY 0xFFFFFFFFu
+#define ARGON2_MIN_TIME 1u
+#define ARGON2_MAX_TIME 0xFFFFFFFFu
+#define ARGON2_MIN_PWD_LENGTH 0u
+#define ARGON2_MAX_PWD_LENGTH 0xFFFFFFFFu
+#define ARGON2_MIN_AD_LENGTH 0u
+#define ARGON2_MAX_AD_LENGTH 0xFFFFFFFFu
+#define ARGON2_MIN_SALT_LENGTH 8u
+#define ARGON2_MAX_SALT_LENGTH 0xFFFFFFFFu
+#define ARGON2_MIN_SECRET 0u
+#define ARGON2_MAX_SECRET 0xFFFFFFFFu
+#define ARGON2_BLOCK_SIZE 1024
+#define ARGON2_QWORDS_IN_BLOCK ((ARGON2_BLOCK_SIZE) / 8)
+#define ARGON2_OWORDS_IN_BLOCK ((ARGON2_BLOCK_SIZE) / 16)
+#define ARGON2_HWORDS_IN_BLOCK ((ARGON2_BLOCK_SIZE) / 32)
+#define ARGON2_512BIT_WORDS_IN_BLOCK ((ARGON2_BLOCK_SIZE) / 64)
+#define ARGON2_ADDRESSES_IN_BLOCK 128
+#define ARGON2_PREHASH_DIGEST_LENGTH 64
+#define ARGON2_PREHASH_SEED_LENGTH \
     (ARGON2_PREHASH_DIGEST_LENGTH + (2 * sizeof(uint32_t)))
 
-# define ARGON2_DEFAULT_OUTLEN 64u
-# define ARGON2_DEFAULT_T_COST 3u
-# define ARGON2_DEFAULT_M_COST ARGON2_MIN_MEMORY
-# define ARGON2_DEFAULT_LANES  1u
-# define ARGON2_DEFAULT_THREADS 1u
-# define ARGON2_DEFAULT_VERSION ARGON2_VERSION_NUMBER
+#define ARGON2_DEFAULT_OUTLEN 64u
+#define ARGON2_DEFAULT_T_COST 3u
+#define ARGON2_DEFAULT_M_COST ARGON2_MIN_MEMORY
+#define ARGON2_DEFAULT_LANES 1u
+#define ARGON2_DEFAULT_THREADS 1u
+#define ARGON2_DEFAULT_VERSION ARGON2_VERSION_NUMBER
 
-# undef G
-# define G(a, b, c, d)                                                        \
-    do {                                                                      \
-        a = a + b + 2 * mul_lower(a, b);                                      \
-        d = rotr64(d ^ a, 32);                                                \
-        c = c + d + 2 * mul_lower(c, d);                                      \
-        b = rotr64(b ^ c, 24);                                                \
-        a = a + b + 2 * mul_lower(a, b);                                      \
-        d = rotr64(d ^ a, 16);                                                \
-        c = c + d + 2 * mul_lower(c, d);                                      \
-        b = rotr64(b ^ c, 63);                                                \
+#undef G
+#define G(a, b, c, d)                    \
+    do {                                 \
+        a = a + b + 2 * mul_lower(a, b); \
+        d = rotr64(d ^ a, 32);           \
+        c = c + d + 2 * mul_lower(c, d); \
+        b = rotr64(b ^ c, 24);           \
+        a = a + b + 2 * mul_lower(a, b); \
+        d = rotr64(d ^ a, 16);           \
+        c = c + d + 2 * mul_lower(c, d); \
+        b = rotr64(b ^ c, 63);           \
     } while ((void)0, 0)
 
-# undef PERMUTATION_P
-# define PERMUTATION_P(v0, v1, v2, v3, v4, v5, v6, v7, v8, v9, v10, v11,      \
-                       v12, v13, v14, v15)                                    \
-    do {                                                                      \
-        G(v0, v4, v8, v12);                                                   \
-        G(v1, v5, v9, v13);                                                   \
-        G(v2, v6, v10, v14);                                                  \
-        G(v3, v7, v11, v15);                                                  \
-        G(v0, v5, v10, v15);                                                  \
-        G(v1, v6, v11, v12);                                                  \
-        G(v2, v7, v8, v13);                                                   \
-        G(v3, v4, v9, v14);                                                   \
+#undef PERMUTATION_P
+#define PERMUTATION_P(v0, v1, v2, v3, v4, v5, v6, v7, v8, v9, v10, v11, \
+    v12, v13, v14, v15)                                                 \
+    do {                                                                \
+        G(v0, v4, v8, v12);                                             \
+        G(v1, v5, v9, v13);                                             \
+        G(v2, v6, v10, v14);                                            \
+        G(v3, v7, v11, v15);                                            \
+        G(v0, v5, v10, v15);                                            \
+        G(v1, v6, v11, v12);                                            \
+        G(v2, v7, v8, v13);                                             \
+        G(v3, v4, v9, v14);                                             \
     } while ((void)0, 0)
 
-# undef PERMUTATION_P_COLUMN
-# define PERMUTATION_P_COLUMN(x, i)                                           \
-    do {                                                                      \
-        uint64_t *base = &x[16 * i];                                          \
-        PERMUTATION_P(                                                        \
-            *base,        *(base + 1),  *(base + 2),  *(base + 3),            \
-            *(base + 4),  *(base + 5),  *(base + 6),  *(base + 7),            \
-            *(base + 8),  *(base + 9),  *(base + 10), *(base + 11),           \
-            *(base + 12), *(base + 13), *(base + 14), *(base + 15)            \
-        );                                                                    \
+#undef PERMUTATION_P_COLUMN
+#define PERMUTATION_P_COLUMN(x, i)                                   \
+    do {                                                             \
+        uint64_t *base = &x[16 * i];                                 \
+        PERMUTATION_P(                                               \
+            *base, *(base + 1), *(base + 2), *(base + 3),            \
+            *(base + 4), *(base + 5), *(base + 6), *(base + 7),      \
+            *(base + 8), *(base + 9), *(base + 10), *(base + 11),    \
+            *(base + 12), *(base + 13), *(base + 14), *(base + 15)); \
     } while ((void)0, 0)
 
-# undef PERMUTATION_P_ROW
-# define PERMUTATION_P_ROW(x, i)                                              \
-    do {                                                                      \
-        uint64_t *base = &x[2 * i];                                           \
-        PERMUTATION_P(                                                        \
-            *base,        *(base + 1),  *(base + 16),  *(base + 17),          \
-            *(base + 32), *(base + 33), *(base + 48),  *(base + 49),          \
-            *(base + 64), *(base + 65), *(base + 80),  *(base + 81),          \
-            *(base + 96), *(base + 97), *(base + 112), *(base + 113)          \
-        );                                                                    \
+#undef PERMUTATION_P_ROW
+#define PERMUTATION_P_ROW(x, i)                                        \
+    do {                                                               \
+        uint64_t *base = &x[2 * i];                                    \
+        PERMUTATION_P(                                                 \
+            *base, *(base + 1), *(base + 16), *(base + 17),            \
+            *(base + 32), *(base + 33), *(base + 48), *(base + 49),    \
+            *(base + 64), *(base + 65), *(base + 80), *(base + 81),    \
+            *(base + 96), *(base + 97), *(base + 112), *(base + 113)); \
     } while ((void)0, 0)
 
 typedef struct {
@@ -143,8 +143,8 @@ typedef enum {
 } ARGON2_VERSION;
 
 typedef enum {
-    ARGON2_D  = 0,
-    ARGON2_I  = 1,
+    ARGON2_D = 0,
+    ARGON2_I = 1,
     ARGON2_ID = 2
 } ARGON2_TYPE;
 
@@ -204,7 +204,7 @@ static void *kdf_argon2i_new(void *provctx);
 static void *kdf_argon2id_new(void *provctx);
 static void kdf_argon2_free(void *vctx);
 static int kdf_argon2_derive(void *vctx, unsigned char *out, size_t outlen,
-                             const OSSL_PARAM params[]);
+    const OSSL_PARAM params[]);
 static void kdf_argon2_reset(void *vctx);
 static int kdf_argon2_ctx_set_threads(KDF_ARGON2 *ctx, uint32_t threads);
 static int kdf_argon2_ctx_set_lanes(KDF_ARGON2 *ctx, uint32_t lanes);
@@ -219,11 +219,11 @@ static int kdf_argon2_set_ctx_params(void *vctx, const OSSL_PARAM params[]);
 static int kdf_argon2_get_ctx_params(void *vctx, OSSL_PARAM params[]);
 static int kdf_argon2_ctx_set_version(KDF_ARGON2 *ctx, uint32_t version);
 static const OSSL_PARAM *kdf_argon2_settable_ctx_params(ossl_unused void *ctx,
-                                                        ossl_unused void *p_ctx);
+    ossl_unused void *p_ctx);
 static const OSSL_PARAM *kdf_argon2_gettable_ctx_params(ossl_unused void *ctx,
-                                                        ossl_unused void *p_ctx);
+    ossl_unused void *p_ctx);
 static int argon2_set_ctx_params(KDF_ARGON2 *ctx, const OSSL_PARAM params[],
-                                 OSSL_PARAM **size_param_ptr);
+    OSSL_PARAM **size_param_ptr);
 
 static ossl_inline uint64_t load64(const uint8_t *src);
 static ossl_inline void store32(uint8_t *dst, uint32_t w);
@@ -238,23 +238,23 @@ static void load_block(BLOCK *dst, const void *input);
 static void store_block(void *output, const BLOCK *src);
 static void fill_first_blocks(uint8_t *blockhash, const KDF_ARGON2 *ctx);
 static void fill_block(const BLOCK *prev, const BLOCK *ref, BLOCK *next,
-                       int with_xor);
+    int with_xor);
 
 static void next_addresses(BLOCK *address_block, BLOCK *input_block,
-                           const BLOCK *zero_block);
+    const BLOCK *zero_block);
 static int data_indep_addressing(const KDF_ARGON2 *ctx, uint32_t pass,
-                                 uint8_t slice);
+    uint8_t slice);
 static uint32_t index_alpha(const KDF_ARGON2 *ctx, uint32_t pass,
-                            uint8_t slice, uint32_t index,
-                            uint32_t pseudo_rand, int same_lane);
+    uint8_t slice, uint32_t index,
+    uint32_t pseudo_rand, int same_lane);
 
 static void fill_segment(const KDF_ARGON2 *ctx, uint32_t pass, uint32_t lane,
-                         uint8_t slice);
+    uint8_t slice);
 
-# if !defined(ARGON2_NO_THREADS)
+#if !defined(ARGON2_NO_THREADS)
 static uint32_t fill_segment_thr(void *thread_data);
 static int fill_mem_blocks_mt(KDF_ARGON2 *ctx);
-# endif
+#endif
 
 static int fill_mem_blocks_st(KDF_ARGON2 *ctx);
 static ossl_inline int fill_memory_blocks(KDF_ARGON2 *ctx);
@@ -264,22 +264,21 @@ static int initialize(KDF_ARGON2 *ctx);
 static void finalize(const KDF_ARGON2 *ctx, void *out);
 
 static int blake2b(EVP_MD *md, EVP_MAC *mac, void *out, size_t outlen,
-                   const void *in, size_t inlen, const void *key,
-                   size_t keylen);
+    const void *in, size_t inlen, const void *key,
+    size_t keylen);
 static int blake2b_long(EVP_MD *md, EVP_MAC *mac, unsigned char *out,
-                        size_t outlen, const void *in, size_t inlen);
+    size_t outlen, const void *in, size_t inlen);
 
 static ossl_inline uint64_t load64(const uint8_t *src)
 {
-    return
-      (((uint64_t)src[0]) << 0)
-    | (((uint64_t)src[1]) << 8)
-    | (((uint64_t)src[2]) << 16)
-    | (((uint64_t)src[3]) << 24)
-    | (((uint64_t)src[4]) << 32)
-    | (((uint64_t)src[5]) << 40)
-    | (((uint64_t)src[6]) << 48)
-    | (((uint64_t)src[7]) << 56);
+    return (((uint64_t)src[0]) << 0)
+        | (((uint64_t)src[1]) << 8)
+        | (((uint64_t)src[2]) << 16)
+        | (((uint64_t)src[3]) << 24)
+        | (((uint64_t)src[4]) << 32)
+        | (((uint64_t)src[5]) << 40)
+        | (((uint64_t)src[6]) << 48)
+        | (((uint64_t)src[7]) << 56);
 }
 
 static ossl_inline void store32(uint8_t *dst, uint32_t w)
@@ -360,20 +359,20 @@ static void fill_first_blocks(uint8_t *blockhash, const KDF_ARGON2 *ctx)
         store32(blockhash + ARGON2_PREHASH_DIGEST_LENGTH, 0);
         store32(blockhash + ARGON2_PREHASH_DIGEST_LENGTH + 4, l);
         blake2b_long(ctx->md, ctx->mac, blockhash_bytes, ARGON2_BLOCK_SIZE,
-                     blockhash, ARGON2_PREHASH_SEED_LENGTH);
+            blockhash, ARGON2_PREHASH_SEED_LENGTH);
         load_block(&ctx->memory[l * ctx->lane_length + 0],
-                   blockhash_bytes);
+            blockhash_bytes);
         store32(blockhash + ARGON2_PREHASH_DIGEST_LENGTH, 1);
         blake2b_long(ctx->md, ctx->mac, blockhash_bytes, ARGON2_BLOCK_SIZE,
-                     blockhash, ARGON2_PREHASH_SEED_LENGTH);
+            blockhash, ARGON2_PREHASH_SEED_LENGTH);
         load_block(&ctx->memory[l * ctx->lane_length + 1],
-                   blockhash_bytes);
+            blockhash_bytes);
     }
     OPENSSL_cleanse(blockhash_bytes, ARGON2_BLOCK_SIZE);
 }
 
 static void fill_block(const BLOCK *prev, const BLOCK *ref,
-                       BLOCK *next, int with_xor)
+    BLOCK *next, int with_xor)
 {
     BLOCK blockR, tmp;
     unsigned i;
@@ -396,7 +395,7 @@ static void fill_block(const BLOCK *prev, const BLOCK *ref,
 }
 
 static void next_addresses(BLOCK *address_block, BLOCK *input_block,
-                           const BLOCK *zero_block)
+    const BLOCK *zero_block)
 {
     input_block->v[6]++;
     fill_block(zero_block, input_block, address_block, 0);
@@ -404,7 +403,7 @@ static void next_addresses(BLOCK *address_block, BLOCK *input_block,
 }
 
 static int data_indep_addressing(const KDF_ARGON2 *ctx, uint32_t pass,
-                                 uint8_t slice)
+    uint8_t slice)
 {
     switch (ctx->type) {
     case ARGON2_I:
@@ -429,8 +428,8 @@ static int data_indep_addressing(const KDF_ARGON2 *ctx, uint32_t pass,
  * Other lanes: (SYNC_POINTS - 1) last segments
  */
 static uint32_t index_alpha(const KDF_ARGON2 *ctx, uint32_t pass,
-                            uint8_t slice, uint32_t index,
-                            uint32_t pseudo_rand, int same_lane)
+    uint8_t slice, uint32_t index,
+    uint32_t pseudo_rand, int same_lane)
 {
     uint32_t ref_area_sz;
     uint64_t rel_pos;
@@ -444,15 +443,13 @@ static uint32_t index_alpha(const KDF_ARGON2 *ctx, uint32_t pass,
         else if (same_lane)
             ref_area_sz = slice * ctx->segment_length + index - 1;
         else
-            ref_area_sz = slice * ctx->segment_length +
-                ((index == 0) ? (-1) : 0);
+            ref_area_sz = slice * ctx->segment_length + ((index == 0) ? (-1) : 0);
         break;
     default:
         if (same_lane)
             ref_area_sz = ctx->lane_length - ctx->segment_length + index - 1;
         else
-            ref_area_sz = ctx->lane_length - ctx->segment_length +
-                ((index == 0) ? (-1) : 0);
+            ref_area_sz = ctx->lane_length - ctx->segment_length + ((index == 0) ? (-1) : 0);
         if (slice != ARGON2_SYNC_POINTS - 1)
             start_pos = (slice + 1) * ctx->segment_length;
         break;
@@ -467,7 +464,7 @@ static uint32_t index_alpha(const KDF_ARGON2 *ctx, uint32_t pass,
 }
 
 static void fill_segment(const KDF_ARGON2 *ctx, uint32_t pass, uint32_t lane,
-                         uint8_t slice)
+    uint8_t slice)
 {
     BLOCK *ref_block = NULL, *curr_block = NULL;
     BLOCK address_block, input_block, zero_block;
@@ -532,7 +529,7 @@ static void fill_segment(const KDF_ARGON2 *ctx, uint32_t pass, uint32_t lane,
 
         /* Computing the number of possible reference block within the lane. */
         ref_index = index_alpha(ctx, pass, slice, j, rnd & 0xFFFFFFFF,
-                                ref_lane == lane);
+            ref_lane == lane);
 
         /* Creating a new block */
         ref_block = ctx->memory + ctx->lane_length * ref_lane + ref_index;
@@ -544,19 +541,19 @@ static void fill_segment(const KDF_ARGON2 *ctx, uint32_t pass, uint32_t lane,
         }
 
         fill_block(ctx->memory + prev_offset, ref_block, curr_block,
-                   pass == 0 ? 0 : 1);
+            pass == 0 ? 0 : 1);
     }
 }
 
-# if !defined(ARGON2_NO_THREADS)
+#if !defined(ARGON2_NO_THREADS)
 
 static uint32_t fill_segment_thr(void *thread_data)
 {
     ARGON2_THREAD_DATA *my_data;
 
-    my_data = (ARGON2_THREAD_DATA *) thread_data;
+    my_data = (ARGON2_THREAD_DATA *)thread_data;
     fill_segment(my_data->ctx, my_data->pos.pass, my_data->pos.lane,
-                 my_data->pos.slice);
+        my_data->pos.slice);
 
     return 0;
 }
@@ -593,7 +590,7 @@ static int fill_mem_blocks_mt(KDF_ARGON2 *ctx)
                 t_data[l].ctx = ctx;
                 memcpy(&(t_data[l].pos), &p, sizeof(ARGON2_POS));
                 t[l] = ossl_crypto_thread_start(ctx->libctx, &fill_segment_thr,
-                                                (void *) &t_data[l]);
+                    (void *)&t_data[l]);
                 if (t[l] == NULL) {
                     for (ll = 0; ll < l; ++ll) {
                         if (ossl_crypto_thread_join(t[ll], NULL) == 0)
@@ -628,7 +625,7 @@ fail:
     return 0;
 }
 
-# endif /* !defined(ARGON2_NO_THREADS) */
+#endif /* !defined(ARGON2_NO_THREADS) */
 
 static int fill_mem_blocks_st(KDF_ARGON2 *ctx)
 {
@@ -643,11 +640,11 @@ static int fill_mem_blocks_st(KDF_ARGON2 *ctx)
 
 static ossl_inline int fill_memory_blocks(KDF_ARGON2 *ctx)
 {
-# if !defined(ARGON2_NO_THREADS)
+#if !defined(ARGON2_NO_THREADS)
     return ctx->threads == 1 ? fill_mem_blocks_st(ctx) : fill_mem_blocks_mt(ctx);
-# else
+#else
     return ctx->threads == 1 ? fill_mem_blocks_st(ctx) : 0;
-# endif
+#endif
 }
 
 static void initial_hash(uint8_t *blockhash, KDF_ARGON2 *ctx)
@@ -665,7 +662,7 @@ static void initial_hash(uint8_t *blockhash, KDF_ARGON2 *ctx)
     args[2] = ctx->m_cost;
     args[3] = ctx->t_cost;
     args[4] = ctx->version;
-    args[5] = (uint32_t) ctx->type;
+    args[5] = (uint32_t)ctx->type;
     args[6] = ctx->pwdlen;
 
     mdctx = EVP_MD_CTX_create();
@@ -673,7 +670,7 @@ static void initial_hash(uint8_t *blockhash, KDF_ARGON2 *ctx)
         goto fail;
 
     for (tmp = 0; tmp < sizeof(args) / sizeof(uint32_t); ++tmp) {
-        store32((uint8_t *) &value, args[tmp]);
+        store32((uint8_t *)&value, args[tmp]);
         if (EVP_DigestUpdate(mdctx, &value, sizeof(value)) != 1)
             goto fail;
     }
@@ -687,7 +684,7 @@ static void initial_hash(uint8_t *blockhash, KDF_ARGON2 *ctx)
         }
     }
 
-    store32((uint8_t *) &value, ctx->saltlen);
+    store32((uint8_t *)&value, ctx->saltlen);
 
     if (EVP_DigestUpdate(mdctx, &value, sizeof(value)) != 1)
         goto fail;
@@ -696,7 +693,7 @@ static void initial_hash(uint8_t *blockhash, KDF_ARGON2 *ctx)
         if (EVP_DigestUpdate(mdctx, ctx->salt, ctx->saltlen) != 1)
             goto fail;
 
-    store32((uint8_t *) &value, ctx->secretlen);
+    store32((uint8_t *)&value, ctx->secretlen);
     if (EVP_DigestUpdate(mdctx, &value, sizeof(value)) != 1)
         goto fail;
 
@@ -709,7 +706,7 @@ static void initial_hash(uint8_t *blockhash, KDF_ARGON2 *ctx)
         }
     }
 
-    store32((uint8_t *) &value, ctx->adlen);
+    store32((uint8_t *)&value, ctx->adlen);
     if (EVP_DigestUpdate(mdctx, &value, sizeof(value)) != 1)
         goto fail;
 
@@ -742,13 +739,13 @@ static int initialize(KDF_ARGON2 *ctx)
 
     if (ctx->memory == NULL) {
         ERR_raise_data(ERR_LIB_PROV, PROV_R_INVALID_MEMORY_SIZE,
-                       "cannot allocate required memory");
+            "cannot allocate required memory");
         return 0;
     }
 
     initial_hash(blockhash, ctx);
     OPENSSL_cleanse(blockhash + ARGON2_PREHASH_DIGEST_LENGTH,
-                    ARGON2_PREHASH_SEED_LENGTH - ARGON2_PREHASH_DIGEST_LENGTH);
+        ARGON2_PREHASH_SEED_LENGTH - ARGON2_PREHASH_DIGEST_LENGTH);
     fill_first_blocks(blockhash, ctx);
     OPENSSL_cleanse(blockhash, ARGON2_PREHASH_SEED_LENGTH);
 
@@ -776,20 +773,20 @@ static void finalize(const KDF_ARGON2 *ctx, void *out)
     /* Hash the result */
     store_block(blockhash_bytes, &blockhash);
     blake2b_long(ctx->md, ctx->mac, out, ctx->outlen, blockhash_bytes,
-                 ARGON2_BLOCK_SIZE);
+        ARGON2_BLOCK_SIZE);
     OPENSSL_cleanse(blockhash.v, ARGON2_BLOCK_SIZE);
     OPENSSL_cleanse(blockhash_bytes, ARGON2_BLOCK_SIZE);
 
     if (ctx->type != ARGON2_D)
         OPENSSL_secure_clear_free(ctx->memory,
-                                  ctx->memory_blocks * sizeof(BLOCK));
+            ctx->memory_blocks * sizeof(BLOCK));
     else
         OPENSSL_clear_free(ctx->memory,
-                           ctx->memory_blocks * sizeof(BLOCK));
+            ctx->memory_blocks * sizeof(BLOCK));
 }
 
 static int blake2b_mac(EVP_MAC *mac, void *out, size_t outlen, const void *in,
-                       size_t inlen, const void *key, size_t keylen)
+    size_t inlen, const void *key, size_t keylen)
 {
     int ret = 0;
     size_t par_n = 0, out_written;
@@ -800,14 +797,14 @@ static int blake2b_mac(EVP_MAC *mac, void *out, size_t outlen, const void *in,
         goto fail;
 
     par[par_n++] = OSSL_PARAM_construct_octet_string(OSSL_MAC_PARAM_KEY,
-                                                     (void *) key, keylen);
+        (void *)key, keylen);
     par[par_n++] = OSSL_PARAM_construct_size_t(OSSL_MAC_PARAM_SIZE, &outlen);
     par[par_n++] = OSSL_PARAM_construct_end();
 
     ret = EVP_MAC_CTX_set_params(ctx, par) == 1
         && EVP_MAC_init(ctx, NULL, 0, NULL) == 1
         && EVP_MAC_update(ctx, in, inlen) == 1
-        && EVP_MAC_final(ctx, out, (size_t *) &out_written, outlen) == 1;
+        && EVP_MAC_final(ctx, out, (size_t *)&out_written, outlen) == 1;
 
 fail:
     EVP_MAC_CTX_free(ctx);
@@ -815,7 +812,7 @@ fail:
 }
 
 static int blake2b_md(EVP_MD *md, void *out, size_t outlen, const void *in,
-                      size_t inlen)
+    size_t inlen)
 {
     int ret = 0;
     EVP_MD_CTX *ctx = NULL;
@@ -836,7 +833,7 @@ static int blake2b_md(EVP_MD *md, void *out, size_t outlen, const void *in,
 }
 
 static int blake2b(EVP_MD *md, EVP_MAC *mac, void *out, size_t outlen,
-                   const void *in, size_t inlen, const void *key, size_t keylen)
+    const void *in, size_t inlen, const void *key, size_t keylen)
 {
     if (out == NULL || outlen == 0)
         return 0;
@@ -848,14 +845,14 @@ static int blake2b(EVP_MD *md, EVP_MAC *mac, void *out, size_t outlen,
 }
 
 static int blake2b_long(EVP_MD *md, EVP_MAC *mac, unsigned char *out,
-                        size_t outlen, const void *in, size_t inlen)
+    size_t outlen, const void *in, size_t inlen)
 {
     int ret = 0;
     EVP_MD_CTX *ctx = NULL;
     uint32_t outlen_curr;
     uint8_t outbuf[BLAKE2B_OUTBYTES];
     uint8_t inbuf[BLAKE2B_OUTBYTES];
-    uint8_t outlen_bytes[sizeof(uint32_t)] = {0};
+    uint8_t outlen_bytes[sizeof(uint32_t)] = { 0 };
     OSSL_PARAM par[2];
     size_t outlen_md;
 
@@ -876,7 +873,8 @@ static int blake2b_long(EVP_MD *md, EVP_MAC *mac, unsigned char *out,
         && EVP_DigestUpdate(ctx, outlen_bytes, sizeof(outlen_bytes)) == 1
         && EVP_DigestUpdate(ctx, in, inlen) == 1
         && EVP_DigestFinal_ex(ctx, (outlen > BLAKE2B_OUTBYTES) ? outbuf : out,
-                              NULL) == 1;
+               NULL)
+            == 1;
 
     if (ret == 0)
         goto fail;
@@ -884,12 +882,13 @@ static int blake2b_long(EVP_MD *md, EVP_MAC *mac, unsigned char *out,
     if (outlen > BLAKE2B_OUTBYTES) {
         memcpy(out, outbuf, BLAKE2B_OUTBYTES / 2);
         out += BLAKE2B_OUTBYTES / 2;
-        outlen_curr = (uint32_t) outlen - BLAKE2B_OUTBYTES / 2;
+        outlen_curr = (uint32_t)outlen - BLAKE2B_OUTBYTES / 2;
 
         while (outlen_curr > BLAKE2B_OUTBYTES) {
             memcpy(inbuf, outbuf, BLAKE2B_OUTBYTES);
             if (blake2b(md, mac, outbuf, BLAKE2B_OUTBYTES, inbuf,
-                        BLAKE2B_OUTBYTES, NULL, 0) != 1)
+                    BLAKE2B_OUTBYTES, NULL, 0)
+                != 1)
                 goto fail;
             memcpy(out, outbuf, BLAKE2B_OUTBYTES / 2);
             out += BLAKE2B_OUTBYTES / 2;
@@ -898,7 +897,8 @@ static int blake2b_long(EVP_MD *md, EVP_MAC *mac, unsigned char *out,
 
         memcpy(inbuf, outbuf, BLAKE2B_OUTBYTES);
         if (blake2b(md, mac, outbuf, outlen_curr, inbuf, BLAKE2B_OUTBYTES,
-                    NULL, 0) != 1)
+                NULL, 0)
+            != 1)
             goto fail;
         memcpy(out, outbuf, outlen_curr);
     }
@@ -1013,7 +1013,7 @@ static void kdf_argon2_free(void *vctx)
 }
 
 static int kdf_argon2_derive(void *vctx, unsigned char *out, size_t outlen,
-                             const OSSL_PARAM params[])
+    const OSSL_PARAM params[])
 {
     KDF_ARGON2 *ctx;
     uint32_t memory_blocks, segment_length;
@@ -1022,14 +1022,14 @@ static int kdf_argon2_derive(void *vctx, unsigned char *out, size_t outlen,
     ctx = (KDF_ARGON2 *)vctx;
 
     if (!ossl_prov_is_running()
-            || !argon2_set_ctx_params(vctx, params, &size_param))
+        || !argon2_set_ctx_params(vctx, params, &size_param))
         return 0;
 
     if (ctx->mac == NULL)
         ctx->mac = EVP_MAC_fetch(ctx->libctx, "blake2bmac", ctx->propq);
     if (ctx->mac == NULL) {
         ERR_raise_data(ERR_LIB_PROV, PROV_R_MISSING_MAC,
-                       "cannot fetch blake2bmac");
+            "cannot fetch blake2bmac");
         return 0;
     }
 
@@ -1037,7 +1037,7 @@ static int kdf_argon2_derive(void *vctx, unsigned char *out, size_t outlen,
         ctx->md = EVP_MD_fetch(ctx->libctx, "blake2b512", ctx->propq);
     if (ctx->md == NULL) {
         ERR_raise_data(ERR_LIB_PROV, PROV_R_MISSING_MESSAGE_DIGEST,
-                       "cannot fetch blake2b512");
+            "cannot fetch blake2b512");
         return 0;
     }
 
@@ -1052,7 +1052,7 @@ static int kdf_argon2_derive(void *vctx, unsigned char *out, size_t outlen,
             ERR_raise(ERR_LIB_PROV, PROV_R_OUTPUT_BUFFER_TOO_SMALL);
             return 0;
         }
-        if (!kdf_argon2_ctx_set_out_length(ctx, (uint32_t) outlen))
+        if (!kdf_argon2_ctx_set_out_length(ctx, (uint32_t)outlen))
             return 0;
     }
 
@@ -1067,30 +1067,30 @@ static int kdf_argon2_derive(void *vctx, unsigned char *out, size_t outlen,
     }
 
     if (ctx->threads > 1) {
-# ifdef ARGON2_NO_THREADS
+#ifdef ARGON2_NO_THREADS
         ERR_raise_data(ERR_LIB_PROV, PROV_R_INVALID_THREAD_POOL_SIZE,
-                       "requested %u threads, single-threaded mode supported only",
-                       ctx->threads);
+            "requested %u threads, single-threaded mode supported only",
+            ctx->threads);
         return 0;
-# else
+#else
         if (ctx->threads > ossl_get_avail_threads(ctx->libctx)) {
             ERR_raise_data(ERR_LIB_PROV, PROV_R_INVALID_THREAD_POOL_SIZE,
-                           "requested %u threads, available: %u",
-                           ctx->threads, ossl_get_avail_threads(ctx->libctx));
+                "requested %u threads, available: %u",
+                ctx->threads, ossl_get_avail_threads(ctx->libctx));
             return 0;
         }
-# endif
+#endif
         if (ctx->threads > ctx->lanes) {
             ERR_raise_data(ERR_LIB_PROV, PROV_R_INVALID_THREAD_POOL_SIZE,
-                           "requested more threads (%u) than lanes (%u)",
-                           ctx->threads, ctx->lanes);
+                "requested more threads (%u) than lanes (%u)",
+                ctx->threads, ctx->lanes);
             return 0;
         }
     }
 
     if (ctx->m_cost < 8 * ctx->lanes) {
         ERR_raise_data(ERR_LIB_PROV, PROV_R_INVALID_MEMORY_SIZE,
-                       "m_cost must be greater or equal than 8 times the number of lanes");
+            "m_cost must be greater or equal than 8 times the number of lanes");
         return 0;
     }
 
@@ -1125,7 +1125,7 @@ static void kdf_argon2_reset(void *vctx)
     KDF_ARGON2 *ctx;
     ARGON2_TYPE type;
 
-    ctx = (KDF_ARGON2 *) vctx;
+    ctx = (KDF_ARGON2 *)vctx;
     type = ctx->type;
     libctx = ctx->libctx;
 
@@ -1155,13 +1155,13 @@ static int kdf_argon2_ctx_set_threads(KDF_ARGON2 *ctx, uint32_t threads)
 {
     if (threads < ARGON2_MIN_THREADS) {
         ERR_raise_data(ERR_LIB_PROV, PROV_R_INVALID_THREAD_POOL_SIZE,
-                       "min threads: %u", ARGON2_MIN_THREADS);
+            "min threads: %u", ARGON2_MIN_THREADS);
         return 0;
     }
 
     if (threads > ARGON2_MAX_THREADS) {
         ERR_raise_data(ERR_LIB_PROV, PROV_R_INVALID_THREAD_POOL_SIZE,
-                       "max threads: %u", ARGON2_MAX_THREADS);
+            "max threads: %u", ARGON2_MAX_THREADS);
         return 0;
     }
 
@@ -1173,13 +1173,13 @@ static int kdf_argon2_ctx_set_lanes(KDF_ARGON2 *ctx, uint32_t lanes)
 {
     if (lanes > ARGON2_MAX_LANES) {
         ERR_raise_data(ERR_LIB_PROV, PROV_R_FAILED_TO_SET_PARAMETER,
-                       "max lanes: %u", ARGON2_MAX_LANES);
+            "max lanes: %u", ARGON2_MAX_LANES);
         return 0;
     }
 
     if (lanes < ARGON2_MIN_LANES) {
         ERR_raise_data(ERR_LIB_PROV, PROV_R_FAILED_TO_SET_PARAMETER,
-                       "min lanes: %u", ARGON2_MIN_LANES);
+            "min lanes: %u", ARGON2_MIN_LANES);
         return 0;
     }
 
@@ -1193,7 +1193,7 @@ static int kdf_argon2_ctx_set_t_cost(KDF_ARGON2 *ctx, uint32_t t_cost)
 
     if (t_cost < ARGON2_MIN_TIME) {
         ERR_raise_data(ERR_LIB_PROV, PROV_R_INVALID_ITERATION_COUNT,
-                       "min: %u", ARGON2_MIN_TIME);
+            "min: %u", ARGON2_MIN_TIME);
         return 0;
     }
 
@@ -1207,7 +1207,7 @@ static int kdf_argon2_ctx_set_m_cost(KDF_ARGON2 *ctx, uint32_t m_cost)
 
     if (m_cost < ARGON2_MIN_MEMORY) {
         ERR_raise_data(ERR_LIB_PROV, PROV_R_INVALID_MEMORY_SIZE, "min: %u",
-                       ARGON2_MIN_MEMORY);
+            ARGON2_MIN_MEMORY);
         return 0;
     }
 
@@ -1225,7 +1225,7 @@ static int kdf_argon2_ctx_set_out_length(KDF_ARGON2 *ctx, uint32_t outlen)
 
     if (outlen < ARGON2_MIN_OUT_LENGTH) {
         ERR_raise_data(ERR_LIB_PROV, PROV_R_INVALID_OUTPUT_LENGTH, "min: %u",
-                       ARGON2_MIN_OUT_LENGTH);
+            ARGON2_MIN_OUT_LENGTH);
         return 0;
     }
 
@@ -1256,7 +1256,7 @@ static int kdf_argon2_ctx_set_secret(KDF_ARGON2 *ctx, const OSSL_PARAM *p)
         return 0;
     }
 
-    ctx->secretlen = (uint32_t) buflen;
+    ctx->secretlen = (uint32_t)buflen;
     return 1;
 }
 
@@ -1278,11 +1278,11 @@ static int kdf_argon2_ctx_set_pwd(KDF_ARGON2 *ctx, const OSSL_PARAM *p)
 
     if (buflen > ARGON2_MAX_PWD_LENGTH) {
         ERR_raise_data(ERR_LIB_PROV, PROV_R_INVALID_SALT_LENGTH, "max: %u",
-                       ARGON2_MAX_PWD_LENGTH);
+            ARGON2_MAX_PWD_LENGTH);
         goto fail;
     }
 
-    ctx->pwdlen = (uint32_t) buflen;
+    ctx->pwdlen = (uint32_t)buflen;
     return 1;
 
 fail:
@@ -1310,17 +1310,17 @@ static int kdf_argon2_ctx_set_salt(KDF_ARGON2 *ctx, const OSSL_PARAM *p)
 
     if (buflen < ARGON2_MIN_SALT_LENGTH) {
         ERR_raise_data(ERR_LIB_PROV, PROV_R_INVALID_SALT_LENGTH, "min: %u",
-                       ARGON2_MIN_SALT_LENGTH);
+            ARGON2_MIN_SALT_LENGTH);
         goto fail;
     }
 
     if (buflen > ARGON2_MAX_SALT_LENGTH) {
         ERR_raise_data(ERR_LIB_PROV, PROV_R_INVALID_SALT_LENGTH, "max: %u",
-                       ARGON2_MAX_SALT_LENGTH);
+            ARGON2_MAX_SALT_LENGTH);
         goto fail;
     }
 
-    ctx->saltlen = (uint32_t) buflen;
+    ctx->saltlen = (uint32_t)buflen;
     return 1;
 
 fail:
@@ -1353,7 +1353,7 @@ static int kdf_argon2_ctx_set_ad(KDF_ARGON2 *ctx, const OSSL_PARAM *p)
         return 0;
     }
 
-    ctx->adlen = (uint32_t) buflen;
+    ctx->adlen = (uint32_t)buflen;
     return 1;
 }
 
@@ -1371,7 +1371,7 @@ static int kdf_argon2_ctx_set_version(KDF_ARGON2 *ctx, uint32_t version)
         return 1;
     default:
         ERR_raise_data(ERR_LIB_PROV, PROV_R_INVALID_MODE,
-                       "invalid Argon2 version");
+            "invalid Argon2 version");
         return 0;
     }
 }
@@ -1392,6 +1392,7 @@ static int set_property_query(KDF_ARGON2 *ctx, const char *propq)
     return 1;
 }
 
+/* clang-format off */
 /* Machine generated by util/perl/OpenSSL/paramnames.pm */
 #ifndef argon2_set_ctx_params_list
 static const OSSL_PARAM argon2_set_ctx_params_list[] = {
@@ -1586,9 +1587,10 @@ static int argon2_set_ctx_params_decoder
 }
 #endif
 /* End of machine generated */
+/* clang-format on */
 
 static int argon2_set_ctx_params(KDF_ARGON2 *ctx, const OSSL_PARAM params[],
-                                 OSSL_PARAM **size_param_ptr)
+    OSSL_PARAM **size_param_ptr)
 {
     struct argon2_set_ctx_params_st p;
     uint32_t u32_value;
@@ -1667,18 +1669,19 @@ static int argon2_set_ctx_params(KDF_ARGON2 *ctx, const OSSL_PARAM params[],
 
 static int kdf_argon2_set_ctx_params(void *vctx, const OSSL_PARAM params[])
 {
-    KDF_ARGON2 *ctx = (KDF_ARGON2 *) vctx;
+    KDF_ARGON2 *ctx = (KDF_ARGON2 *)vctx;
     OSSL_PARAM *size_param;
 
     return argon2_set_ctx_params(ctx, params, &size_param);
 }
 
 static const OSSL_PARAM *kdf_argon2_settable_ctx_params(ossl_unused void *ctx,
-                                                        ossl_unused void *p_ctx)
+    ossl_unused void *p_ctx)
 {
     return argon2_set_ctx_params_list;
 }
 
+/* clang-format off */
 /* Machine generated by util/perl/OpenSSL/paramnames.pm */
 #ifndef argon2_get_ctx_params_list
 static const OSSL_PARAM argon2_get_ctx_params_list[] = {
@@ -1715,11 +1718,12 @@ static int argon2_get_ctx_params_decoder
 }
 #endif
 /* End of machine generated */
+/* clang-format on */
 
 static int kdf_argon2_get_ctx_params(void *vctx, OSSL_PARAM params[])
 {
     struct argon2_get_ctx_params_st p;
-    KDF_ARGON2 *ctx = (KDF_ARGON2 *) vctx;
+    KDF_ARGON2 *ctx = (KDF_ARGON2 *)vctx;
 
     if (ctx == NULL || !argon2_get_ctx_params_decoder(params, &p))
         return 0;
@@ -1731,50 +1735,50 @@ static int kdf_argon2_get_ctx_params(void *vctx, OSSL_PARAM params[])
 }
 
 static const OSSL_PARAM *kdf_argon2_gettable_ctx_params(ossl_unused void *ctx,
-                                                        ossl_unused void *p_ctx)
+    ossl_unused void *p_ctx)
 {
     return argon2_get_ctx_params_list;
 }
 
 const OSSL_DISPATCH ossl_kdf_argon2i_functions[] = {
-    { OSSL_FUNC_KDF_NEWCTX, (void(*)(void))kdf_argon2i_new },
-    { OSSL_FUNC_KDF_FREECTX, (void(*)(void))kdf_argon2_free },
-    { OSSL_FUNC_KDF_RESET, (void(*)(void))kdf_argon2_reset },
-    { OSSL_FUNC_KDF_DERIVE, (void(*)(void))kdf_argon2_derive },
+    { OSSL_FUNC_KDF_NEWCTX, (void (*)(void))kdf_argon2i_new },
+    { OSSL_FUNC_KDF_FREECTX, (void (*)(void))kdf_argon2_free },
+    { OSSL_FUNC_KDF_RESET, (void (*)(void))kdf_argon2_reset },
+    { OSSL_FUNC_KDF_DERIVE, (void (*)(void))kdf_argon2_derive },
     { OSSL_FUNC_KDF_SETTABLE_CTX_PARAMS,
-      (void(*)(void))kdf_argon2_settable_ctx_params },
-    { OSSL_FUNC_KDF_SET_CTX_PARAMS, (void(*)(void))kdf_argon2_set_ctx_params },
+        (void (*)(void))kdf_argon2_settable_ctx_params },
+    { OSSL_FUNC_KDF_SET_CTX_PARAMS, (void (*)(void))kdf_argon2_set_ctx_params },
     { OSSL_FUNC_KDF_GETTABLE_CTX_PARAMS,
-      (void(*)(void))kdf_argon2_gettable_ctx_params },
-    { OSSL_FUNC_KDF_GET_CTX_PARAMS, (void(*)(void))kdf_argon2_get_ctx_params },
+        (void (*)(void))kdf_argon2_gettable_ctx_params },
+    { OSSL_FUNC_KDF_GET_CTX_PARAMS, (void (*)(void))kdf_argon2_get_ctx_params },
     OSSL_DISPATCH_END
 };
 
 const OSSL_DISPATCH ossl_kdf_argon2d_functions[] = {
-    { OSSL_FUNC_KDF_NEWCTX, (void(*)(void))kdf_argon2d_new },
-    { OSSL_FUNC_KDF_FREECTX, (void(*)(void))kdf_argon2_free },
-    { OSSL_FUNC_KDF_RESET, (void(*)(void))kdf_argon2_reset },
-    { OSSL_FUNC_KDF_DERIVE, (void(*)(void))kdf_argon2_derive },
+    { OSSL_FUNC_KDF_NEWCTX, (void (*)(void))kdf_argon2d_new },
+    { OSSL_FUNC_KDF_FREECTX, (void (*)(void))kdf_argon2_free },
+    { OSSL_FUNC_KDF_RESET, (void (*)(void))kdf_argon2_reset },
+    { OSSL_FUNC_KDF_DERIVE, (void (*)(void))kdf_argon2_derive },
     { OSSL_FUNC_KDF_SETTABLE_CTX_PARAMS,
-      (void(*)(void))kdf_argon2_settable_ctx_params },
-    { OSSL_FUNC_KDF_SET_CTX_PARAMS, (void(*)(void))kdf_argon2_set_ctx_params },
+        (void (*)(void))kdf_argon2_settable_ctx_params },
+    { OSSL_FUNC_KDF_SET_CTX_PARAMS, (void (*)(void))kdf_argon2_set_ctx_params },
     { OSSL_FUNC_KDF_GETTABLE_CTX_PARAMS,
-      (void(*)(void))kdf_argon2_gettable_ctx_params },
-    { OSSL_FUNC_KDF_GET_CTX_PARAMS, (void(*)(void))kdf_argon2_get_ctx_params },
+        (void (*)(void))kdf_argon2_gettable_ctx_params },
+    { OSSL_FUNC_KDF_GET_CTX_PARAMS, (void (*)(void))kdf_argon2_get_ctx_params },
     OSSL_DISPATCH_END
 };
 
 const OSSL_DISPATCH ossl_kdf_argon2id_functions[] = {
-    { OSSL_FUNC_KDF_NEWCTX, (void(*)(void))kdf_argon2id_new },
-    { OSSL_FUNC_KDF_FREECTX, (void(*)(void))kdf_argon2_free },
-    { OSSL_FUNC_KDF_RESET, (void(*)(void))kdf_argon2_reset },
-    { OSSL_FUNC_KDF_DERIVE, (void(*)(void))kdf_argon2_derive },
+    { OSSL_FUNC_KDF_NEWCTX, (void (*)(void))kdf_argon2id_new },
+    { OSSL_FUNC_KDF_FREECTX, (void (*)(void))kdf_argon2_free },
+    { OSSL_FUNC_KDF_RESET, (void (*)(void))kdf_argon2_reset },
+    { OSSL_FUNC_KDF_DERIVE, (void (*)(void))kdf_argon2_derive },
     { OSSL_FUNC_KDF_SETTABLE_CTX_PARAMS,
-      (void(*)(void))kdf_argon2_settable_ctx_params },
-    { OSSL_FUNC_KDF_SET_CTX_PARAMS, (void(*)(void))kdf_argon2_set_ctx_params },
+        (void (*)(void))kdf_argon2_settable_ctx_params },
+    { OSSL_FUNC_KDF_SET_CTX_PARAMS, (void (*)(void))kdf_argon2_set_ctx_params },
     { OSSL_FUNC_KDF_GETTABLE_CTX_PARAMS,
-      (void(*)(void))kdf_argon2_gettable_ctx_params },
-    { OSSL_FUNC_KDF_GET_CTX_PARAMS, (void(*)(void))kdf_argon2_get_ctx_params },
+        (void (*)(void))kdf_argon2_gettable_ctx_params },
+    { OSSL_FUNC_KDF_GET_CTX_PARAMS, (void (*)(void))kdf_argon2_get_ctx_params },
     OSSL_DISPATCH_END
 };
 
