@@ -1,12 +1,14 @@
 /*
- * Copyright 2016-2025 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2016-2026 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
  * in the file LICENSE in the source distribution or at
  * https://www.openssl.org/source/license.html
  */
+/* clang-format off */
 
+/* clang-format on */
 
 /*
  * Refer to "The TLS Protocol Version 1.0" Section 5
@@ -86,14 +88,14 @@ static OSSL_FUNC_kdf_gettable_ctx_params_fn kdf_tls1_prf_gettable_ctx_params;
 static OSSL_FUNC_kdf_get_ctx_params_fn kdf_tls1_prf_get_ctx_params;
 
 static int tls1_prf_alg(EVP_MAC_CTX *mdctx, EVP_MAC_CTX *sha1ctx,
-                        const unsigned char *sec, size_t slen,
-                        const unsigned char *seed, size_t seed_len,
-                        unsigned char *out, size_t olen);
+    const unsigned char *sec, size_t slen,
+    const unsigned char *seed, size_t seed_len,
+    unsigned char *out, size_t olen);
 
-#define TLS_MD_MASTER_SECRET_CONST        "\x6d\x61\x73\x74\x65\x72\x20\x73\x65\x63\x72\x65\x74"
-#define TLS_MD_MASTER_SECRET_CONST_SIZE   13
+#define TLS_MD_MASTER_SECRET_CONST "\x6d\x61\x73\x74\x65\x72\x20\x73\x65\x63\x72\x65\x74"
+#define TLS_MD_MASTER_SECRET_CONST_SIZE 13
 
-#define TLSPRF_MAX_SEEDS    6
+#define TLSPRF_MAX_SEEDS 6
 
 /* TLS KDF kdf context structure */
 typedef struct {
@@ -159,21 +161,21 @@ static void *kdf_tls1_prf_dup(void *vctx)
     dest = kdf_tls1_prf_new(src->provctx);
     if (dest != NULL) {
         if (src->P_hash != NULL
-                    && (dest->P_hash = EVP_MAC_CTX_dup(src->P_hash)) == NULL)
+            && (dest->P_hash = EVP_MAC_CTX_dup(src->P_hash)) == NULL)
             goto err;
         if (src->P_sha1 != NULL
-                    && (dest->P_sha1 = EVP_MAC_CTX_dup(src->P_sha1)) == NULL)
+            && (dest->P_sha1 = EVP_MAC_CTX_dup(src->P_sha1)) == NULL)
             goto err;
         if (!ossl_prov_memdup(src->sec, src->seclen, &dest->sec, &dest->seclen))
             goto err;
         if (!ossl_prov_memdup(src->seed, src->seedlen, &dest->seed,
-                              &dest->seedlen))
+                &dest->seedlen))
             goto err;
         OSSL_FIPS_IND_COPY(dest, src)
     }
     return dest;
 
- err:
+err:
     kdf_tls1_prf_free(dest);
     return NULL;
 }
@@ -192,13 +194,14 @@ static int fips_ems_check_passed(TLS1_PRF *ctx)
      * as "extended master secret".
      */
     int ems_approved = (ctx->seedlen < TLS_MD_MASTER_SECRET_CONST_SIZE
-                       || memcmp(ctx->seed, TLS_MD_MASTER_SECRET_CONST,
-                                 TLS_MD_MASTER_SECRET_CONST_SIZE) != 0);
+        || memcmp(ctx->seed, TLS_MD_MASTER_SECRET_CONST,
+               TLS_MD_MASTER_SECRET_CONST_SIZE)
+            != 0);
 
     if (!ems_approved) {
         if (!OSSL_FIPS_IND_ON_UNAPPROVED(ctx, OSSL_FIPS_IND_SETTABLE0,
-                                         libctx, "TLS_PRF", "EMS",
-                                         ossl_fips_config_tls1_prf_ems_check)) {
+                libctx, "TLS_PRF", "EMS",
+                ossl_fips_config_tls1_prf_ems_check)) {
             ERR_raise(ERR_LIB_PROV, PROV_R_EMS_NOT_ENABLED);
             return 0;
         }
@@ -222,8 +225,8 @@ static int fips_digest_check_passed(TLS1_PRF *ctx, const EVP_MD *md)
 
     if (digest_unapproved) {
         if (!OSSL_FIPS_IND_ON_UNAPPROVED(ctx, OSSL_FIPS_IND_SETTABLE1,
-                                         libctx, "TLS_PRF", "Digest",
-                                         ossl_fips_config_tls1_prf_digest_check)) {
+                libctx, "TLS_PRF", "Digest",
+                ossl_fips_config_tls1_prf_digest_check)) {
             ERR_raise(ERR_LIB_PROV, PROV_R_DIGEST_NOT_ALLOWED);
             return 0;
         }
@@ -238,8 +241,8 @@ static int fips_key_check_passed(TLS1_PRF *ctx)
 
     if (!key_approved) {
         if (!OSSL_FIPS_IND_ON_UNAPPROVED(ctx, OSSL_FIPS_IND_SETTABLE2,
-                                         libctx, "TLS_PRF", "Key size",
-                                         ossl_fips_config_tls1_prf_key_check)) {
+                libctx, "TLS_PRF", "Key size",
+                ossl_fips_config_tls1_prf_key_check)) {
             ERR_raise(ERR_LIB_PROV, PROV_R_INVALID_KEY_LENGTH);
             return 0;
         }
@@ -249,7 +252,7 @@ static int fips_key_check_passed(TLS1_PRF *ctx)
 #endif
 
 static int kdf_tls1_prf_derive(void *vctx, unsigned char *key, size_t keylen,
-                               const OSSL_PARAM params[])
+    const OSSL_PARAM params[])
 {
     TLS1_PRF *ctx = (TLS1_PRF *)vctx;
 
@@ -279,11 +282,12 @@ static int kdf_tls1_prf_derive(void *vctx, unsigned char *key, size_t keylen,
 #endif
 
     return tls1_prf_alg(ctx->P_hash, ctx->P_sha1,
-                        ctx->sec, ctx->seclen,
-                        ctx->seed, ctx->seedlen,
-                        key, keylen);
+        ctx->sec, ctx->seclen,
+        ctx->seed, ctx->seedlen,
+        key, keylen);
 }
 
+/* clang-format off */
 /* Machine generated by util/perl/OpenSSL/paramnames.pm */
 #ifndef tls1prf_set_ctx_params_list
 static const OSSL_PARAM tls1prf_set_ctx_params_list[] = {
@@ -476,6 +480,7 @@ static int tls1prf_set_ctx_params_decoder
 }
 #endif
 /* End of machine generated */
+/* clang-format on */
 
 static int kdf_tls1_prf_set_ctx_params(void *vctx, const OSSL_PARAM params[])
 {
@@ -505,20 +510,21 @@ static int kdf_tls1_prf_set_ctx_params(void *vctx, const OSSL_PARAM params[])
 
         if (OPENSSL_strcasecmp(dgst, OSSL_DIGEST_NAME_MD5_SHA1) == 0) {
             if (!ossl_prov_macctx_load(&ctx->P_hash, NULL, NULL, NULL,
-                                       p.propq, p.engine,
-                                       OSSL_MAC_NAME_HMAC, NULL,
-                                       OSSL_DIGEST_NAME_MD5, libctx))
+                    p.propq, p.engine,
+                    OSSL_MAC_NAME_HMAC, NULL,
+                    OSSL_DIGEST_NAME_MD5, libctx))
                 return 0;
             if (!ossl_prov_macctx_load(&ctx->P_sha1, NULL, NULL, NULL,
-                                       p.propq, p.engine,
-                                       OSSL_MAC_NAME_HMAC, NULL,
-                                       OSSL_DIGEST_NAME_SHA1, libctx))
+                    p.propq, p.engine,
+                    OSSL_MAC_NAME_HMAC, NULL,
+                    OSSL_DIGEST_NAME_SHA1, libctx))
                 return 0;
         } else {
             EVP_MAC_CTX_free(ctx->P_sha1);
+            ctx->P_sha1 = NULL;
             if (!ossl_prov_macctx_load(&ctx->P_hash, NULL, NULL, p.digest,
-                                       p.propq, p.engine,
-                                       OSSL_MAC_NAME_HMAC, NULL, NULL, libctx))
+                    p.propq, p.engine,
+                    OSSL_MAC_NAME_HMAC, NULL, NULL, libctx))
                 return 0;
         }
 
@@ -547,7 +553,7 @@ static int kdf_tls1_prf_set_ctx_params(void *vctx, const OSSL_PARAM params[])
         OPENSSL_clear_free(ctx->sec, ctx->seclen);
         ctx->sec = NULL;
         if (!OSSL_PARAM_get_octet_string(p.secret, (void **)&ctx->sec, 0,
-                                         &ctx->seclen))
+                &ctx->seclen))
             return 0;
 
 #ifdef FIPS_MODULE
@@ -573,7 +579,7 @@ static int kdf_tls1_prf_set_ctx_params(void *vctx, const OSSL_PARAM params[])
                 int err = 0;
 
                 if (!OSSL_PARAM_get_octet_string_ptr(p.seed[i],
-                                                     vals + n, sizes + n))
+                        vals + n, sizes + n))
                     return 0;
 
                 seedlen = safe_add_size_t(seedlen, sizes[n], &err);
@@ -585,7 +591,7 @@ static int kdf_tls1_prf_set_ctx_params(void *vctx, const OSSL_PARAM params[])
 
         if (seedlen != ctx->seedlen) {
             unsigned char *seed = OPENSSL_clear_realloc(ctx->seed,
-                                                        ctx->seedlen, seedlen);
+                ctx->seedlen, seedlen);
 
             if (seed == NULL)
                 return 0;
@@ -603,11 +609,12 @@ static int kdf_tls1_prf_set_ctx_params(void *vctx, const OSSL_PARAM params[])
 }
 
 static const OSSL_PARAM *kdf_tls1_prf_settable_ctx_params(
-        ossl_unused void *ctx, ossl_unused void *provctx)
+    ossl_unused void *ctx, ossl_unused void *provctx)
 {
     return tls1prf_set_ctx_params_list;
 }
 
+/* clang-format off */
 /* Machine generated by util/perl/OpenSSL/paramnames.pm */
 #ifndef tls1prf_get_ctx_params_list
 static const OSSL_PARAM tls1prf_get_ctx_params_list[] = {
@@ -668,6 +675,7 @@ static int tls1prf_get_ctx_params_decoder
 }
 #endif
 /* End of machine generated */
+/* clang-format on */
 
 static int kdf_tls1_prf_get_ctx_params(void *vctx, OSSL_PARAM params[])
 {
@@ -686,25 +694,25 @@ static int kdf_tls1_prf_get_ctx_params(void *vctx, OSSL_PARAM params[])
 }
 
 static const OSSL_PARAM *kdf_tls1_prf_gettable_ctx_params(
-        ossl_unused void *ctx, ossl_unused void *provctx)
+    ossl_unused void *ctx, ossl_unused void *provctx)
 {
     return tls1prf_get_ctx_params_list;
 }
 
 const OSSL_DISPATCH ossl_kdf_tls1_prf_functions[] = {
-    { OSSL_FUNC_KDF_NEWCTX, (void(*)(void))kdf_tls1_prf_new },
-    { OSSL_FUNC_KDF_DUPCTX, (void(*)(void))kdf_tls1_prf_dup },
-    { OSSL_FUNC_KDF_FREECTX, (void(*)(void))kdf_tls1_prf_free },
-    { OSSL_FUNC_KDF_RESET, (void(*)(void))kdf_tls1_prf_reset },
-    { OSSL_FUNC_KDF_DERIVE, (void(*)(void))kdf_tls1_prf_derive },
+    { OSSL_FUNC_KDF_NEWCTX, (void (*)(void))kdf_tls1_prf_new },
+    { OSSL_FUNC_KDF_DUPCTX, (void (*)(void))kdf_tls1_prf_dup },
+    { OSSL_FUNC_KDF_FREECTX, (void (*)(void))kdf_tls1_prf_free },
+    { OSSL_FUNC_KDF_RESET, (void (*)(void))kdf_tls1_prf_reset },
+    { OSSL_FUNC_KDF_DERIVE, (void (*)(void))kdf_tls1_prf_derive },
     { OSSL_FUNC_KDF_SETTABLE_CTX_PARAMS,
-      (void(*)(void))kdf_tls1_prf_settable_ctx_params },
+        (void (*)(void))kdf_tls1_prf_settable_ctx_params },
     { OSSL_FUNC_KDF_SET_CTX_PARAMS,
-      (void(*)(void))kdf_tls1_prf_set_ctx_params },
+        (void (*)(void))kdf_tls1_prf_set_ctx_params },
     { OSSL_FUNC_KDF_GETTABLE_CTX_PARAMS,
-      (void(*)(void))kdf_tls1_prf_gettable_ctx_params },
+        (void (*)(void))kdf_tls1_prf_gettable_ctx_params },
     { OSSL_FUNC_KDF_GET_CTX_PARAMS,
-      (void(*)(void))kdf_tls1_prf_get_ctx_params },
+        (void (*)(void))kdf_tls1_prf_get_ctx_params },
     OSSL_DISPATCH_END
 };
 
@@ -729,9 +737,9 @@ const OSSL_DISPATCH ossl_kdf_tls1_prf_functions[] = {
  *     A(i) = HMAC_<hash>(secret, A(i-1))
  */
 static int tls1_prf_P_hash(EVP_MAC_CTX *ctx_init,
-                           const unsigned char *sec, size_t sec_len,
-                           const unsigned char *seed, size_t seed_len,
-                           unsigned char *out, size_t olen)
+    const unsigned char *sec, size_t sec_len,
+    const unsigned char *seed, size_t seed_len,
+    unsigned char *out, size_t olen)
 {
     size_t chunk;
     EVP_MAC_CTX *ctx = NULL, *ctx_Ai = NULL;
@@ -787,7 +795,7 @@ static int tls1_prf_P_hash(EVP_MAC_CTX *ctx_init,
         olen -= chunk;
     }
     ret = 1;
- err:
+err:
     EVP_MAC_CTX_free(ctx);
     EVP_MAC_CTX_free(ctx_Ai);
     OPENSSL_cleanse(Ai, sizeof(Ai));
@@ -815,9 +823,9 @@ static int tls1_prf_P_hash(EVP_MAC_CTX *ctx_init,
  *   PRF(secret, label, seed) = P_<hash>(secret, label + seed)
  */
 static int tls1_prf_alg(EVP_MAC_CTX *mdctx, EVP_MAC_CTX *sha1ctx,
-                        const unsigned char *sec, size_t slen,
-                        const unsigned char *seed, size_t seed_len,
-                        unsigned char *out, size_t olen)
+    const unsigned char *sec, size_t slen,
+    const unsigned char *seed, size_t seed_len,
+    unsigned char *out, size_t olen)
 {
     if (sha1ctx != NULL) {
         /* TLS v1.0 and TLS v1.1 */
@@ -828,14 +836,14 @@ static int tls1_prf_alg(EVP_MAC_CTX *mdctx, EVP_MAC_CTX *sha1ctx,
         size_t L_S2 = L_S1;
 
         if (!tls1_prf_P_hash(mdctx, sec, L_S1,
-                             seed, seed_len, out, olen))
+                seed, seed_len, out, olen))
             return 0;
 
         if ((tmp = OPENSSL_malloc(olen)) == NULL)
             return 0;
 
         if (!tls1_prf_P_hash(sha1ctx, sec + slen - L_S2, L_S2,
-                             seed, seed_len, tmp, olen)) {
+                seed, seed_len, tmp, olen)) {
             OPENSSL_clear_free(tmp, olen);
             return 0;
         }
